@@ -10,7 +10,7 @@ def sitemap_download(request):
         from core.sitemaps import CommonSitemap
         return sitemap(request, {'generic': CommonSitemap})
     except ImportError:
-        return Http404()
+        raise Http404()
 
 
 def sitemap_tree(request):
